GiniEstimation: GiniEstimation

Description Usage Arguments Value Examples

Description

Estimate by simulation the mean, median and deciles of hatG if X is continuous random variable

Usage

1
GiniEstimation(cdf, mu, n, m, a, b)

Arguments

cdf

for the supposed distribution(continuous)

mu

for theoritical expectation

n

for size of random numbers

m

for repeating times

a

for the better xlim for histogram(u can choose a better one when u observed its distribution in histogram with random a b )

b

for the better xlim for histogram(u can choose a better one when u observed its distribution in histogram with random a b )

Value

mean median and deciles ,a density histograms of the replicatesn

Examples

1
2
3
4
## Not run: 
GiniEstimation(rlnorm,exp(0.5),1e3,1e2,0.45,0.65)#The standard lognormal

## End(Not run)

peachandbeach/StatComp18069 documentation built on May 5, 2019, 11:07 p.m.