Description Usage Arguments Value Examples
Estimate by simulation the mean, median and deciles of hatG if X is continuous random variable
1 | GiniEstimation(cdf, mu, n, m, a, b)
|
cdf |
for the supposed distribution(continuous) |
mu |
for theoritical expectation |
n |
for size of random numbers |
m |
for repeating times |
a |
for the better xlim for histogram(u can choose a better one when u observed its distribution in histogram with random a b ) |
b |
for the better xlim for histogram(u can choose a better one when u observed its distribution in histogram with random a b ) |
mean median and deciles ,a density histograms of the replicatesn
1 2 3 4 | ## Not run:
GiniEstimation(rlnorm,exp(0.5),1e3,1e2,0.45,0.65)#The standard lognormal
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.